@@ -21,13 +21,13 @@
 #include "checks.h"
 #include "directories.h"
 #include "gwrappers.h"
-#include "htmlbrowser.h"
 #include "xmlutils.h"
 #include "settings.h"
 #include "bible.h"
 #include "style.h"
 #include "tiny_utilities.h"
 #include "utilities.h"
+#include "gtkwrappers.h"
 
 
 void checks_output_references_comments(const vector < ustring > &references, const vector < ustring > &comments)
@@ -99,7 +99,7 @@ void DisplayCheckingResults::word_inventory(const vector < ustring > &words, con
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "wordinventory.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::usfm_count(const vector < ustring > &usfms, const vector < unsigned int >&count, const ustring & stylesheet)
@@ -134,7 +134,7 @@ void DisplayCheckingResults::usfm_count(const vector < ustring > &usfms, const v
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "usfmcount.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::character_count(const vector < ustring > &chars, const vector < unsigned int >&count)
@@ -172,7 +172,7 @@ void DisplayCheckingResults::character_count(const vector < ustring > &chars, co
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "charactercount.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::references_inventory(const vector < ustring > &verses, const vector < ustring > &references)
@@ -204,7 +204,7 @@ void DisplayCheckingResults::references_inventory(const vector < ustring > &vers
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "referenceinventory.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::ot_quotations_in_nt(const vector <ustring> nt_refs, const vector <ustring> nt_texts, const vector <VectorUstring>& ot_refs, const vector <VectorUstring>& ot_texts, const gchar * mainheading)
@@ -252,7 +252,7 @@ void DisplayCheckingResults::ot_quotations_in_nt(const vector <ustring> nt_refs,
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "nt-ot-quotations.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::parallel_passages(const vector < OtNtParallelDataSection > &data, const gchar * mainheading)
@@ -277,7 +277,7 @@ void DisplayCheckingResults::parallel_passages(const vector < OtNtParallelDataSe
   ustring outputfilename;
   outputfilename = gw_build_filename(directories_get_temp(), "parallelpassages.html");
   write_lines(outputfilename, html);
-  htmlbrowser(outputfilename);
+  gtkw_show_uri (outputfilename);
 }
 
 void DisplayCheckingResults::start(const ustring & title)
