@@ -44,7 +44,7 @@ BooknamesDialog::BooknamesDialog(const map <unsigned int, ustring>& books, const
   gtk_window_set_modal(GTK_WINDOW(resourcebooksdialog), TRUE);
   gtk_window_set_type_hint(GTK_WINDOW(resourcebooksdialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-  dialog_vbox1 = GTK_DIALOG(resourcebooksdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(resourcebooksdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 2);
@@ -72,7 +72,7 @@ BooknamesDialog::BooknamesDialog(const map <unsigned int, ustring>& books, const
   gtk_container_add(GTK_CONTAINER(scrolledwindow1), treeview1);
   gtk_tree_view_set_reorderable(GTK_TREE_VIEW(treeview1), TRUE);
 
-  dialog_action_area1 = GTK_DIALOG(resourcebooksdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(resourcebooksdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -81,14 +81,14 @@ BooknamesDialog::BooknamesDialog(const map <unsigned int, ustring>& books, const
   cancelbutton1 = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(resourcebooksdialog), cancelbutton1, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton1), true);
 
   shortcuts.stockbutton(cancelbutton1);
 
   okbutton1 = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(resourcebooksdialog), okbutton1, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton1), true);
 
   shortcuts.stockbutton(okbutton1);
 
