@@ -40,13 +40,15 @@ CheckDialog::CheckDialog(CheckDialogType checkdialogtype)
 {
   // Save and initialize variables.
   mycheckdialogtype = checkdialogtype;
+  extern Settings *settings;
+  const ustring project_name = settings->genconfig.project_get().c_str();
 
   checkdialog = gtk_dialog_new();
-  gtk_window_set_title(GTK_WINDOW(checkdialog), "Check");
+  gtk_window_set_title(GTK_WINDOW(checkdialog), project_name.c_str());
   gtk_window_set_position(GTK_WINDOW(checkdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(checkdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(checkdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(checkdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 4);
@@ -60,6 +62,7 @@ CheckDialog::CheckDialog(CheckDialogType checkdialogtype)
   radiobutton_sort2 = NULL;
   radiobutton_sort3 = NULL;
   selectprojectgui = NULL;
+  selectparallelprojectgui = NULL;
   entry_capitalization_punctuation = NULL;
   checkbutton_repetition_case = NULL;
   entry_matching_pairs_ignore = NULL;
@@ -149,30 +152,32 @@ CheckDialog::CheckDialog(CheckDialogType checkdialogtype)
     book_selection_setup();
     break;
   case cdtSynopticParallelsNT:
-    information_setup("Shows the synoptic parallel passages of the New Testament.");
+    information_setup("Shows the synoptic parallel passages of the " + project_name + " New Testament.");
     include_verse_text_setup();
+    parallel_project_setup();
     book_selection_setup();
     break;
   case cdtParallelsOT:
-    information_setup("Shows the parallel passages of the Old Testament.");
+    information_setup("Shows the parallel passages of the " + project_name + " Old Testament.");
     include_verse_text_setup();
+    parallel_project_setup();
     book_selection_setup();
     break;
   }
 
-  dialog_action_area1 = GTK_DIALOG(checkdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(checkdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(checkdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(checkdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   g_signal_connect((gpointer) okbutton, "clicked", G_CALLBACK(on_okbutton_clicked), gpointer(this));
 
@@ -191,6 +196,8 @@ CheckDialog::~CheckDialog()
 {
   if (selectprojectgui)
     delete selectprojectgui;
+  if (selectparallelprojectgui)
+	  delete selectparallelprojectgui;
   gtk_widget_destroy(checkdialog);
 }
 
@@ -199,9 +206,9 @@ int CheckDialog::run()
   return gtk_dialog_run(GTK_DIALOG(checkdialog));
 }
 
-void CheckDialog::information_setup(const gchar * information)
+void CheckDialog::information_setup(const ustring information)
 {
-  infolabel = gtk_label_new(information);
+  infolabel = gtk_label_new(information.c_str());
   gtk_widget_show(infolabel);
   gtk_container_add(GTK_CONTAINER(vbox1), infolabel);
   gtk_label_set_line_wrap(GTK_LABEL(infolabel), TRUE);
@@ -1105,6 +1112,8 @@ void CheckDialog::set_gui()
     gtk_widget_set_sensitive(button_repetition_show, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_repetition_show)));
     gtk_widget_set_sensitive(button_repetition_ignore, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_repetition_ignore)));
   }
+
+
 }
 
 void CheckDialog::word_count_setup()
@@ -1180,6 +1189,35 @@ void CheckDialog::on_wordcount_entry1()
   }
 }
 
+void CheckDialog::parallel_project_setup()
+{
+	  extern Settings *settings;
+
+	  checkbutton_include_second_project = gtk_check_button_new_with_mnemonic("_Compare with another project:");
+	  gtk_widget_show(checkbutton_include_second_project);
+	  gtk_box_pack_start(GTK_BOX(vbox1), checkbutton_include_second_project, TRUE, TRUE, 0);
+
+	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_include_second_project), settings->session.check_include_second_project);
+
+	  g_signal_connect_after((gpointer) checkbutton_include_second_project, "clicked", G_CALLBACK(on_include_second_project_activate), gpointer(this));
+
+	 selectparallelprojectgui = new SelectProjectGui(0);
+	 selectparallelprojectgui->build(vbox1, "", settings->genconfig.check_markers_compare_project_get());
+}
+
+void CheckDialog::on_include_second_project_activate(GtkButton * button, gpointer user_data)
+{
+  ((CheckDialog *) user_data)->on_include_second_project();
+}
+
+void CheckDialog::on_include_second_project()
+{
+  bool active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_include_second_project));
+  selectparallelprojectgui->set_sensitive (active);
+  if (active)
+	  selectparallelprojectgui->focus();
+}
+
 void CheckDialog::include_verse_text_setup()
 {
   checkbutton_include_verse_text = gtk_check_button_new_with_mnemonic("_Include verse text");
@@ -1228,6 +1266,9 @@ void CheckDialog::on_okbutton()
     settings->genconfig.check_markers_compare_ignore_set(gtk_entry_get_text(GTK_ENTRY(entry_compare_ignore)));
     settings->genconfig.check_markers_compare_ignore_verse_zero_set(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_compare_ignore_verse_zero)));
   }
+
+
+
   // Words - capitalization.
   if (entry_capitalization_punctuation) {
     settings->genconfig.check_capitalization_punctuation_set(remove_spaces(gtk_entry_get_text(GTK_ENTRY(entry_capitalization_punctuation))));
@@ -1260,6 +1301,16 @@ void CheckDialog::on_okbutton()
   if (checkbutton_include_verse_text) {
     settings->session.check_include_verse_text = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_include_verse_text));
   }
+
+  //Parallel passages - second project comparison
+  if (selectparallelprojectgui) {
+  	  settings->genconfig.check_markers_compare_project_set(selectparallelprojectgui->project);
+  }
+
+  if (checkbutton_include_second_project) {
+	    settings->session.check_include_second_project = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_include_second_project));
+  }
+
   // Output in OT order.
   if (checkbutton_output_in_ot_order) {
     settings->session.check_output_in_ot_order = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_output_in_ot_order));
