@@ -43,7 +43,7 @@ EditListDialog::EditListDialog(vector <ustring> * lines, const ustring & title,
   gtk_window_set_modal(GTK_WINDOW(editlistdialog), TRUE);
   gtk_window_set_resizable(GTK_WINDOW(editlistdialog), FALSE);
 
-  dialog_vbox1 = GTK_DIALOG(editlistdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(editlistdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 0);
@@ -202,7 +202,7 @@ EditListDialog::EditListDialog(vector <ustring> * lines, const ustring & title,
     buttonpointer++;
   }
 
-  dialog_action_area1 = GTK_DIALOG(editlistdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(editlistdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -211,12 +211,12 @@ EditListDialog::EditListDialog(vector <ustring> * lines, const ustring & title,
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(editlistdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(editlistdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   g_signal_connect_after((gpointer) treeview1, "cursor_changed", G_CALLBACK(on_treeview1_cursor_changed), gpointer(this));
   g_signal_connect_after((gpointer) treeview1, "move_cursor", G_CALLBACK(on_treeview1_move_cursor), gpointer(this));
