@@ -48,7 +48,7 @@ EditStatusDialog::EditStatusDialog(const ustring & project_in, unsigned int book
   gtk_window_set_position(GTK_WINDOW(editstatusdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(editstatusdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(editstatusdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG (editstatusdialog));
   gtk_widget_show(dialog_vbox1);
 
   hbox = gtk_hbox_new(FALSE, 4);
@@ -133,7 +133,7 @@ EditStatusDialog::EditStatusDialog(const ustring & project_in, unsigned int book
     statusbuttons.push_back(checkbutton_status);
   }
 
-  dialog_action_area1 = GTK_DIALOG(editstatusdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(editstatusdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -142,12 +142,12 @@ EditStatusDialog::EditStatusDialog(const ustring & project_in, unsigned int book
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(editstatusdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(editstatusdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   g_signal_connect_after((gpointer) treeview_books, "button_release_event", G_CALLBACK(on_treeview_books_button_event), gpointer(this));
   g_signal_connect_after((gpointer) treeview_books, "key_release_event", G_CALLBACK(on_treeview_books_key_event), gpointer(this));
