@@ -33,7 +33,7 @@ FontColorDialog::FontColorDialog(bool initial_use_default_font, const ustring &
   gtk_window_set_position(GTK_WINDOW(fontcolordialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(fontcolordialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(fontcolordialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG (fontcolordialog));
   gtk_widget_show(dialog_vbox1);
 
   checkbutton_font = gtk_check_button_new_with_mnemonic("Use default font");
@@ -125,7 +125,7 @@ FontColorDialog::FontColorDialog(bool initial_use_default_font, const ustring &
   gtk_widget_show(colorbutton_selection);
   gtk_table_attach(GTK_TABLE(table1), colorbutton_selection, 1, 2, 3, 4, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
-  dialog_action_area1 = GTK_DIALOG(fontcolordialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(fontcolordialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -134,12 +134,12 @@ FontColorDialog::FontColorDialog(bool initial_use_default_font, const ustring &
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(fontcolordialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(fontcolordialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(cancelbutton);
   shortcuts.stockbutton(okbutton);
