@@ -48,7 +48,7 @@ ImportNotesDialog::ImportNotesDialog(int dummy)
   gtk_window_set_modal(GTK_WINDOW(importnotesdialog), TRUE);
   gtk_window_set_type_hint(GTK_WINDOW(importnotesdialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-  dialog_vbox1 = GTK_DIALOG(importnotesdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(importnotesdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 0);
@@ -161,9 +161,9 @@ ImportNotesDialog::ImportNotesDialog(int dummy)
   forwardbutton = gtk_button_new_from_stock("gtk-go-forward");
   gtk_widget_show(forwardbutton);
   gtk_box_pack_start(GTK_BOX(hbox1), forwardbutton, FALSE, FALSE, 0);
-  GTK_WIDGET_SET_FLAGS(forwardbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (forwardbutton), true);
 
-  dialog_action_area1 = GTK_DIALOG(importnotesdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(importnotesdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -172,13 +172,13 @@ ImportNotesDialog::ImportNotesDialog(int dummy)
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(importnotesdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   applybutton = gtk_button_new_from_stock("gtk-apply");
   gtk_widget_show(applybutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(importnotesdialog), applybutton, GTK_RESPONSE_APPLY);
   gtk_widget_set_sensitive(applybutton, FALSE);
-  GTK_WIDGET_SET_FLAGS(applybutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (applybutton), true);
 
   g_signal_connect((gpointer) select_directory_button, "clicked", G_CALLBACK(on_select_file_button_clicked), gpointer(this));
   g_signal_connect((gpointer) backbutton, "clicked", G_CALLBACK(on_backbutton_clicked), gpointer(this));
