@@ -39,7 +39,7 @@ NewStylesheetDialog::NewStylesheetDialog(const ustring & worksheet)
     gtk_window_set_title(GTK_WINDOW(newstylesheetdialog), "New stylesheet");
   gtk_window_set_position(GTK_WINDOW(newstylesheetdialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-  dialog_vbox1 = GTK_DIALOG(newstylesheetdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG (newstylesheetdialog));
   gtk_widget_show(dialog_vbox1);
 
   hbox2 = gtk_hbox_new(FALSE, 4);
@@ -164,7 +164,7 @@ NewStylesheetDialog::NewStylesheetDialog(const ustring & worksheet)
     gtk_tree_selection_set_mode(select1, GTK_SELECTION_SINGLE);
   }
 
-  dialog_action_area1 = GTK_DIALOG(newstylesheetdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(newstylesheetdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -173,12 +173,12 @@ NewStylesheetDialog::NewStylesheetDialog(const ustring & worksheet)
   cancelbutton1 = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(newstylesheetdialog), cancelbutton1, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton1), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(newstylesheetdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(cancelbutton1);
   shortcuts.stockbutton(okbutton);
