@@ -39,7 +39,7 @@ OriginReferencesDialog::OriginReferencesDialog(int dummy)
   gtk_window_set_position(GTK_WINDOW(originreferencesdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(originreferencesdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(originreferencesdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(originreferencesdialog));
   gtk_widget_show(dialog_vbox1);
 
   label3 = gtk_label_new("This tool can update all the footnotes, endnotes and crossreferences in the project.");
@@ -167,7 +167,7 @@ OriginReferencesDialog::OriginReferencesDialog(int dummy)
   gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton_text_label), radiobutton_remove_group);
   radiobutton_remove_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton_text_label));
 
-  dialog_action_area1 = GTK_DIALOG(originreferencesdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(originreferencesdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -176,12 +176,12 @@ OriginReferencesDialog::OriginReferencesDialog(int dummy)
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(originreferencesdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(originreferencesdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(cancelbutton);
   shortcuts.stockbutton(okbutton);
