@@ -76,7 +76,7 @@ ProjectDialog::ProjectDialog(bool newproject)
   gtk_window_set_modal(GTK_WINDOW(projectdialog), TRUE);
   gtk_window_set_type_hint(GTK_WINDOW(projectdialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-  dialog_vbox1 = GTK_DIALOG(projectdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(projectdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 0);
@@ -280,7 +280,7 @@ ProjectDialog::ProjectDialog(bool newproject)
 
   shortcuts.button(button_dictionaries);
 
-  dialog_action_area1 = GTK_DIALOG(projectdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(projectdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -289,13 +289,13 @@ ProjectDialog::ProjectDialog(bool newproject)
   cancelbutton1 = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(projectdialog), cancelbutton1, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton1), true);
 
   okbutton1 = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(projectdialog), okbutton1, GTK_RESPONSE_OK);
   gtk_widget_set_sensitive(okbutton1, FALSE);
-  GTK_WIDGET_SET_FLAGS(okbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton1), true);
 
   shortcuts.stockbutton(cancelbutton1);
   shortcuts.stockbutton(okbutton1);
@@ -595,14 +595,19 @@ void ProjectDialog::on_book_delete()
     if (gtkw_dialog_question(projectdialog, "Are you really sure to delete something worth perhaps months of work?") != GTK_RESPONSE_YES)
       return;
     vector < unsigned int >ids = books_type_to_ids(btUnknown);
+    ProgressWindow progresswindow("Deleting books", false);
+    progresswindow.set_iterate(0, 1, ids.size());
     for (unsigned int i = 0; i < ids.size(); i++) {
       // Remove the book.
       if (selection.find(ids[i]) != selection.end()) {
         project_remove_book(currentprojectname, ids[i]);
       }
+      progresswindow.iterate();
     }
+
   }
   // Update GUI.
+
   set_gui();
 }
 
