@@ -38,7 +38,7 @@
 #include "gwrappers.h"
 #include "directories.h"
 #include "screen.h"
-#include "htmlbrowser.h"
+#include "gtkwrappers.h"
 #include "roman.h"
 #include "combobox.h"
 
@@ -63,7 +63,7 @@ ResourceConverterDialog::ResourceConverterDialog(const ustring & working_directo
   gtk_window_set_position(GTK_WINDOW(resourceconverterdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(resourceconverterdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(resourceconverterdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(resourceconverterdialog));
   gtk_widget_show(dialog_vbox1);
 
   label1 = gtk_label_new("");
@@ -74,7 +74,7 @@ ResourceConverterDialog::ResourceConverterDialog(const ustring & working_directo
   build_table_and_type(shortcuts);
 
   // Dialog action.
-  dialog_action_area1 = GTK_DIALOG(resourceconverterdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(resourceconverterdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -86,13 +86,15 @@ ResourceConverterDialog::ResourceConverterDialog(const ustring & working_directo
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(resourceconverterdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
+
   shortcuts.stockbutton(cancelbutton);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(resourceconverterdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
+
   shortcuts.stockbutton(okbutton);
 
   gtk_widget_set_sensitive(okbutton, false);
@@ -599,7 +601,7 @@ void ResourceConverterDialog::on_view_file_button()
 {
   ustring tempfile = gw_build_filename(directories_get_temp(), "resource-converter-view-file");
   write_lines(tempfile, lines);
-  htmlbrowser(tempfile, false);
+  gtkw_show_uri (tempfile, false);
 }
 
 
