@@ -45,7 +45,7 @@ ReviewAnchorsDialog::ReviewAnchorsDialog(vector < unsigned int >*books, vector <
   gtk_window_set_position(GTK_WINDOW(reviewanchorsdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(reviewanchorsdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(reviewanchorsdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(reviewanchorsdialog));
   gtk_widget_show(dialog_vbox1);
 
   label1 = gtk_label_new("Review the anchors that will be placed.\nTo remove some anchors,\nselect them and press the Delete key.");
@@ -91,7 +91,7 @@ ReviewAnchorsDialog::ReviewAnchorsDialog(vector < unsigned int >*books, vector <
 
   shortcuts.label(label3);
 
-  dialog_action_area1 = GTK_DIALOG(reviewanchorsdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(reviewanchorsdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -100,13 +100,13 @@ ReviewAnchorsDialog::ReviewAnchorsDialog(vector < unsigned int >*books, vector <
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(reviewanchorsdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(reviewanchorsdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
-
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
+  
   shortcuts.stockbutton(cancelbutton);
   shortcuts.stockbutton(okbutton);
   shortcuts.process();
@@ -165,7 +165,7 @@ bool ReviewAnchorsDialog::treeview_key_press_handler(GdkEventKey * event)
 // Handles pressing keys in the treeview.
 {
   // Take action.
-  if (event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete) {
+  if (event->keyval == GDK_KEY_Delete || event->keyval == GDK_KEY_KP_Delete) {
     // Delete each selected row.
     vector < GtkTreeIter > iters;
     gtk_tree_selection_selected_foreach(select, ReviewAnchorsDialog::on_collect_iters, gpointer(&iters));
