@@ -64,7 +64,7 @@ bookset: Indicator for the caller's relevant books.
   gtk_window_set_position(GTK_WINDOW(selectbooksdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(selectbooksdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(selectbooksdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(selectbooksdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 0);
@@ -257,7 +257,7 @@ bookset: Indicator for the caller's relevant books.
 
   shortcuts.label(label10);
 
-  dialog_action_area1 = GTK_DIALOG(selectbooksdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(selectbooksdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -272,14 +272,14 @@ bookset: Indicator for the caller's relevant books.
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(selectbooksdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   shortcuts.stockbutton(cancelbutton);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(selectbooksdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(okbutton);
 
@@ -394,7 +394,7 @@ gboolean SelectBooksDialog::on_treeviewbooks_key_press_event(GtkWidget * widget,
 gboolean SelectBooksDialog::on_treeviewbooks_key_press(GdkEventKey * event)
 {
   // Take special action on Enter: OK button.
-  if (event->keyval == GDK_Return || event->keyval == GDK_KP_Enter) {
+  if (event->keyval == GDK_KEY_Return || event->keyval == GDK_KEY_KP_Enter) {
     on_okbutton();
     gtk_dialog_response(GTK_DIALOG(selectbooksdialog), GTK_RESPONSE_OK);
     return true;
