@@ -44,7 +44,7 @@ SelectChaptersDialog::SelectChaptersDialog(const ustring & project, unsigned int
   gtk_window_set_position(GTK_WINDOW(selectchaptersdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(selectchaptersdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(selectchaptersdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(selectchaptersdialog));
   gtk_widget_show(dialog_vbox1);
 
   table1 = gtk_table_new(4, 5, false);
@@ -164,7 +164,7 @@ SelectChaptersDialog::SelectChaptersDialog(const ustring & project, unsigned int
 
   shortcuts.stockbutton(button_delete);
 
-  dialog_action_area1 = GTK_DIALOG(selectchaptersdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(selectchaptersdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -173,12 +173,12 @@ SelectChaptersDialog::SelectChaptersDialog(const ustring & project, unsigned int
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(selectchaptersdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(selectchaptersdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(cancelbutton);
   shortcuts.stockbutton(okbutton);
