@@ -44,7 +44,7 @@ TidyDialog::TidyDialog(int dummy)
   gtk_window_set_modal(GTK_WINDOW(tidydialog), TRUE);
   gtk_window_set_type_hint(GTK_WINDOW(tidydialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-  dialog_vbox1 = GTK_DIALOG(tidydialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG(tidydialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox1 = gtk_vbox_new(FALSE, 2);
@@ -122,7 +122,7 @@ TidyDialog::TidyDialog(int dummy)
   shortcuts.button(checkbutton_space_before_punctuation);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_space_before_punctuation), settings->genconfig.tidy_space_before_punctuation_get());
 
-  dialog_action_area1 = GTK_DIALOG(tidydialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(tidydialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -131,14 +131,14 @@ TidyDialog::TidyDialog(int dummy)
   cancelbutton1 = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(tidydialog), cancelbutton1, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton1), true);
 
   shortcuts.stockbutton(cancelbutton1);
 
   okbutton1 = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton1);
   gtk_dialog_add_action_widget(GTK_DIALOG(tidydialog), okbutton1, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton1, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton1), true);
 
   shortcuts.stockbutton(okbutton1);
 
