@@ -33,7 +33,7 @@ ViewPlanningDialog::ViewPlanningDialog(int dummy)
   gtk_window_set_position(GTK_WINDOW(viewstatusdialog), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(viewstatusdialog), TRUE);
 
-  dialog_vbox1 = GTK_DIALOG(viewstatusdialog)->vbox;
+  dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG (viewstatusdialog));
   gtk_widget_show(dialog_vbox1);
 
   vbox4 = gtk_vbox_new(FALSE, 0);
@@ -84,7 +84,7 @@ ViewPlanningDialog::ViewPlanningDialog(int dummy)
 
   shortcuts.button(checkbutton_csv_export);
 
-  dialog_action_area1 = GTK_DIALOG(viewstatusdialog)->action_area;
+  dialog_action_area1 = gtk_dialog_get_action_area (GTK_DIALOG(viewstatusdialog));
   gtk_widget_show(dialog_action_area1);
   gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
@@ -93,12 +93,12 @@ ViewPlanningDialog::ViewPlanningDialog(int dummy)
   cancelbutton = gtk_button_new_from_stock("gtk-cancel");
   gtk_widget_show(cancelbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(viewstatusdialog), cancelbutton, GTK_RESPONSE_CANCEL);
-  GTK_WIDGET_SET_FLAGS(cancelbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (cancelbutton), true);
 
   okbutton = gtk_button_new_from_stock("gtk-ok");
   gtk_widget_show(okbutton);
   gtk_dialog_add_action_widget(GTK_DIALOG(viewstatusdialog), okbutton, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS(okbutton, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (GTK_WIDGET (okbutton), true);
 
   shortcuts.stockbutton(cancelbutton);
   shortcuts.stockbutton(okbutton);
