@@ -89,13 +89,13 @@ FloatingWindow::FloatingWindow(GtkWidget * layout_in, WindowID window_id_in, ust
   label_status2 = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "label_status2"));
   g_signal_connect ((gpointer) eventbox_status2, "button_press_event", G_CALLBACK (on_widget_button_press_event), gpointer (this));
 
-  hscrollbar_status = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "hscrollbar_status"));
-  g_signal_connect ((gpointer) hscrollbar_status, "button_press_event", G_CALLBACK (on_widget_button_press_event), gpointer (this));
-  g_signal_connect ((gpointer) hscrollbar_status, "button_press_event", G_CALLBACK (on_status_bar_button_press_event), gpointer (this));
-  g_signal_connect ((gpointer) hscrollbar_status, "button_release_event", G_CALLBACK (on_status_bar_button_release_event), gpointer (this));
-  g_signal_connect ((gpointer) hscrollbar_status, "motion_notify_event", G_CALLBACK (on_status_bar_motion_notify_event), gpointer (this));
-  g_signal_connect ((gpointer) hscrollbar_status, "enter_notify_event", G_CALLBACK (on_statusbar_enter_notify_event), gpointer (this));
-  g_signal_connect ((gpointer) hscrollbar_status, "leave_notify_event", G_CALLBACK (on_statusbar_leave_notify_event), gpointer (this));
+  widget_resizer = GTK_WIDGET (gtk_builder_get_object (gtkbuilder, "widget_resizer"));
+  g_signal_connect ((gpointer) widget_resizer, "button_press_event", G_CALLBACK (on_widget_button_press_event), gpointer (this));
+  g_signal_connect ((gpointer) widget_resizer, "button_press_event", G_CALLBACK (on_status_bar_button_press_event), gpointer (this));
+  g_signal_connect ((gpointer) widget_resizer, "button_release_event", G_CALLBACK (on_status_bar_button_release_event), gpointer (this));
+  g_signal_connect ((gpointer) widget_resizer, "motion_notify_event", G_CALLBACK (on_status_bar_motion_notify_event), gpointer (this));
+  g_signal_connect ((gpointer) widget_resizer, "enter_notify_event", G_CALLBACK (on_statusbar_enter_notify_event), gpointer (this));
+  g_signal_connect ((gpointer) widget_resizer, "leave_notify_event", G_CALLBACK (on_statusbar_leave_notify_event), gpointer (this));
 
   // Do the display handling.
   display(startup);
@@ -159,7 +159,7 @@ gboolean FloatingWindow::on_title_bar_motion_notify (GdkEventMotion *event)
     if (previous_root_x >= 0) {
       bool move_box = false;
       if (event_x != previous_root_x) {
-        gint new_x = my_gdk_rectangle.x + event_x - previous_root_x;
+        guint new_x = my_gdk_rectangle.x + event_x - previous_root_x;
         // The window does not move beyond the left or right side 
         if (new_x >= 0) {
           if ((new_x + my_gdk_rectangle.width) <= layout_width) {
@@ -169,7 +169,7 @@ gboolean FloatingWindow::on_title_bar_motion_notify (GdkEventMotion *event)
         }
       }
       if (event_y != previous_root_y) {
-        gint new_y = my_gdk_rectangle.y + event_y - previous_root_y;
+        guint new_y = my_gdk_rectangle.y + event_y - previous_root_y;
         // The window does not move beyond the top or bottom.
         if (new_y >= 0) {
           if ((new_y + my_gdk_rectangle.height) <= layout_height) {
@@ -238,7 +238,7 @@ gboolean FloatingWindow::on_status_bar_motion_notify (GdkEventMotion *event)
     if (previous_root_x >= 0) {
       bool resize_box = false;
       if (event_x != previous_root_x) {
-        gint new_width = my_gdk_rectangle.width + event_x - previous_root_x;
+        guint new_width = my_gdk_rectangle.width + event_x - previous_root_x;
         // Window should not become too narrow, or too wide for the screen.
         if (new_width >= 100) {
           if ((my_gdk_rectangle.x + new_width) <= layout_width) {
@@ -248,7 +248,7 @@ gboolean FloatingWindow::on_status_bar_motion_notify (GdkEventMotion *event)
         }
       }
       if (event_y != previous_root_y) {
-        gint new_height = my_gdk_rectangle.height + event_y - previous_root_y;
+        guint new_height = my_gdk_rectangle.height + event_y - previous_root_y;
         // Window should not become too short, or too tall for the screen.
         if (new_height >= 100) {
           if ((my_gdk_rectangle.y + new_height) <= layout_height) {
@@ -278,7 +278,7 @@ gboolean FloatingWindow::on_titlebar_enter_notify (GdkEventCrossing *event)
 {
   // Set the cursor to a shape that shows that the title bar can be moved around.
   GtkWidget *toplevel_widget = gtk_widget_get_toplevel(label_title);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   GdkCursor *cursor = gdk_cursor_new(GDK_FLEUR);
   gdk_window_set_cursor(gdk_window, cursor);
   gdk_cursor_unref (cursor);
@@ -296,7 +296,7 @@ gboolean FloatingWindow::on_titlebar_leave_notify (GdkEventCrossing *event)
 {
   // Restore the original cursor.
   GtkWidget * toplevel_widget = gtk_widget_get_toplevel(label_title);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   gdk_window_set_cursor(gdk_window, NULL);
   return false;
 }
@@ -311,8 +311,8 @@ gboolean FloatingWindow::on_statusbar_enter_notify_event (GtkWidget *widget, Gdk
 gboolean FloatingWindow::on_statusbar_enter_notify (GdkEventCrossing *event)
 {
   // Set the cursor to a shape that shows that the status bar can be used to resize the window.
-  GtkWidget *toplevel_widget = gtk_widget_get_toplevel(hscrollbar_status);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GtkWidget *toplevel_widget = gtk_widget_get_toplevel(widget_resizer);
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   GdkCursor *cursor = gdk_cursor_new(GDK_BOTTOM_RIGHT_CORNER);
   gdk_window_set_cursor(gdk_window, cursor);
   gdk_cursor_unref (cursor);
@@ -329,8 +329,8 @@ gboolean FloatingWindow::on_statusbar_leave_notify_event (GtkWidget *widget, Gdk
 gboolean FloatingWindow::on_statusbar_leave_notify (GdkEventCrossing *event)
 {
   // Restore the original cursor.
-  GtkWidget * toplevel_widget = gtk_widget_get_toplevel(hscrollbar_status);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GtkWidget * toplevel_widget = gtk_widget_get_toplevel(widget_resizer);
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   gdk_window_set_cursor(gdk_window, NULL);
   return false;
 }
@@ -353,7 +353,7 @@ gboolean FloatingWindow::on_label_close_enter_notify (GdkEventCrossing *event)
 {
   // Set the cursor to a shape that shows that the action label can be clicked.
   GtkWidget *toplevel_widget = gtk_widget_get_toplevel(label_close);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   GdkCursor *cursor = gdk_cursor_new(GDK_HAND2);
   gdk_window_set_cursor(gdk_window, cursor);
   gdk_cursor_unref (cursor);
@@ -371,7 +371,7 @@ gboolean FloatingWindow::on_label_close_leave_notify (GdkEventCrossing *event)
 {
   // Restore the original cursor.
   GtkWidget * toplevel_widget = gtk_widget_get_toplevel(label_close);
-  GdkWindow *gdk_window = toplevel_widget->window;
+  GdkWindow *gdk_window = gtk_widget_get_window (toplevel_widget);
   gdk_window_set_cursor(gdk_window, NULL);
   return false;
 }
