@@ -22,7 +22,7 @@
 #include "tiny_utilities.h"
 #include "directories.h"
 #include "gwrappers.h"
-#include "htmlbrowser.h"
+#include "gtkwrappers.h"
 
 
 HtmlWriter::HtmlWriter(const ustring & title, bool include_java_scripts, bool include_bibledit_css, bool include_bar_graph_css)
@@ -119,7 +119,7 @@ HtmlWriter::~HtmlWriter()
   xmlTextWriterFlush(writer);
   ustring filename = gw_build_filename(directories_get_temp(), "document.html");
   g_file_set_contents(filename.c_str(), (const gchar *)buffer->content, -1, NULL);
-  htmlbrowser(filename, false);
+  gtkw_show_uri (filename, false);
   if (writer)
     xmlFreeTextWriter(writer);
   if (buffer)
