@@ -149,7 +149,7 @@ void WindowCheckKeyterms::go_to_term(unsigned int id)
 
 void WindowCheckKeyterms::copy_clipboard()
 {
-  if (GTK_WIDGET_HAS_FOCUS(htmlview_terms)) {
+  if (gtk_widget_has_focus (htmlview_terms)) {
     // Copy text to the clipboard.
     gtk_html_copy (GTK_HTML (htmlview_terms));
 
@@ -612,9 +612,15 @@ void WindowCheckKeyterms::html_write_keyterms (HtmlWriter2& htmlwriter, unsigned
             verse.erase (0, startpositions[i] - processposition + lengths[i]);
             processposition = startpositions[i] + lengths[i];
           }
+          // Add whatever is left over of the verse. This could be the full verse in case it wasn't processed.
+          htmlwriter.text_add (verse);
+        }
+        else
+        {
+        	htmlwriter.highlight_open();
+        	htmlwriter.text_add (verse);
+        	htmlwriter.highlight_close();
         }
-        // Add whatever is left over of the verse. This could be the full verse in case it wasn't processed.
-        htmlwriter.text_add (verse);
 
         // Proceed to next.
         htmlwriter.paragraph_open ();
